Cypress.Commands.add('typeIntoUi5Input', { prevSubject: 'element' }, (subject, text, options = {}) => {
    cy.wrap(subject)
        .findShadowInput()
        .type(text, { force: true, ...options });
});
Cypress.Commands.add('clearUi5Input', { prevSubject: 'element' }, (subject, text, options = {}) => {
    cy.wrap(subject)
        .findShadowInput()
        .clear({ force: true, ...options });
});
Cypress.Commands.add('typeIntoUi5InputWithDelay', { prevSubject: 'element' }, (subject, text, delay = 500, options = {}) => {
    cy.wrap(subject)
        .findShadowInput()
        .wait(delay)
        .type(text, { force: true, ...options });
});
Cypress.Commands.add('typeIntoUi5TextArea', { prevSubject: 'element' }, (subject, text, options = {}) => {
    cy.wrap(subject)
        .shadow()
        .find('textarea')
        .type(text, { force: true, ...options });
});
Cypress.Commands.add('toggleUi5Checkbox', { prevSubject: 'element' }, (subject) => {
    cy.wrap(subject).findShadowInput().click({ force: true });
});
Cypress.Commands.add('toggleUi5Switch', { prevSubject: 'element' }, (subject) => {
    cy.wrap(subject).findShadowInput().click({ force: true });
});
Cypress.Commands.add('clickUi5RadioButton', { prevSubject: 'element' }, (subject) => {
    cy.wrap(subject).findShadowInput().click({ force: true });
});
Cypress.Commands.add('closeUi5PopupWithEsc', () => {
    cy.get('body').type('{esc}', { force: true });
});
Cypress.Commands.add('clickUi5ListItemByText', (text) => {
    cy.contains(text).find('li').click({ force: true });
});
Cypress.Commands.add('clickUi5SelectOptionByText', { prevSubject: 'element' }, (subject, text, options = {}) => {
    cy.wrap(subject).then(async ($select) => {
        // @ts-expect-error: cannot set $select to use SelectDomRef
        const domRef = await $select.get(0).getStaticAreaItemDomRef();
        cy.wrap(domRef).contains(text).click(options);
    });
});
Cypress.Commands.add('clickUi5SelectOption', { prevSubject: 'element' }, (subject, options = {}) => {
    cy.wrap(subject).then(($option) => {
        // @ts-expect-error: cannot set $option to use OptionDomRef
        const domRef = $option.get(0).getDomRef();
        cy.wrap(domRef).click(options);
    });
});
Cypress.Commands.add('clickDropdownMenuItemByText', { prevSubject: 'element' }, (subject, text, options = {}) => {
    cy.wrap(subject).then(async ($dropdown) => {
        // @ts-expect-error: ui5-webcomponent types are not bundled in
        const staticArea = await $dropdown.get(0).getStaticAreaItemDomRef();
        cy.wrap(staticArea).find('[ui5-responsive-popover][open]').should('be.visible');
        // necessary as otherwise focusing the ui5-li is flaky
        cy.wait(300);
        cy.wrap(staticArea)
            .contains(text)
            .then(async ($li) => {
            await $li.get(0).focus();
            cy.wrap($li)
                .find('li')
                .click({ force: true, ...options });
        });
    });
});
Cypress.Commands.add('clickDropdownMenuItem', { prevSubject: 'element' }, (subject, options = {}) => {
    cy.wrap(subject).then(($option) => {
        // @ts-expect-error: ui5-webcomponent types are not bundled in
        const domRef = $option.get(0).getDomRef();
        cy.wrap(domRef)
            .find('li')
            .click({ force: true, ...options });
    });
});
Cypress.Commands.add('openDropDownByClick', { prevSubject: 'element' }, (subject, options = {}) => {
    if (subject.get(0).hasAttribute('ui5-multi-combobox')) {
        // mcb needs a lot of calculation time to make the popover available
        cy.wait(500);
    }
    cy.wrap(subject).shadow().find('[input-icon]').click(options);
});
export {};
